pub enum HttpResponseError {
Various(String),
JsonDecode(String),
Forbidden,
InternalServerError,
ServiceUnavailable,
ReqwestError(Error),
}Expand description
Represents errors around HTTP connection.
Variants
Various(String)
Uses when an error cannot be categorised any more.
JsonDecode(String)
Uses when decoding JSON failed.
Forbidden
For representing HTTP status code 403.
InternalServerError
For representing HTTP status code 500.
For representing HTTP status code 503.
ReqwestError(Error)
Convert from the errors from reqwest crate to the domain specific error type.