pub enum ValidationError {
OutOfRange {
msg: String,
},
InvalidToken {
msg: String,
},
}Expand description
Represents errors around validation.
Variants
OutOfRange
Uses when a value is out of the specific range.
InvalidToken
Uses when unexpected token is passed to a value.